
//
// Simple slide show example with SFML
// Copyright: Heinrich Hussmann, LMU, 2016
//

#include <SFML/Audio.hpp>
#include <SFML/Graphics.hpp>
#include "ResourcePath.hpp"
#include <array>

//Global dimensions
const int SCREEN_WIDTH = 712;
const int SCREEN_HEIGHT = 712;
const int OFFSET_HOR = 100;
const int OFFSET_VER = 100;

//Directory name for pictures
const std::string gPicsDir = "pics";

//Picture file names
const int NUM_PICS = 4;
std::array<std::string, NUM_PICS> gPicFiles = {"frog.jpg","cows.jpg","elephant.jpg","tiger.jpg"};

const sf::Color bg = sf::Color(255, 228, 95, 255);  //background color
const sf::Time interval = sf::seconds(4.);


int main(int, char const**) {
    // Create the main window
    sf::RenderWindow window(sf::VideoMode(SCREEN_WIDTH, SCREEN_HEIGHT), "SFML Slide Show");
    
    //Load pictures
    sf::Texture loadedPics[NUM_PICS];
    for(int i = 0; i < NUM_PICS; i++) {
        std::string picPath = resourcePath()+gPicsDir+"/"+gPicFiles[i];
        if (!loadedPics[i].loadFromFile(picPath)) {
            return EXIT_FAILURE;
        }
    }
    
    //Create a sprite to display
    sf::Sprite sprite;
    sprite.setScale(sf::Vector2f(2.f, 2.f));
    sprite.setPosition(sf::Vector2f(OFFSET_HOR, OFFSET_VER));
    
    //Main loop
    int slideIndex = 0; //Index of picture to be shown
    bool updatePicture = true; //Do we need to change the picture?
    sf::Clock clock; //Create and start timer
    sf::Time timer;
    
    while (window.isOpen()) {
        
        //Display next picture if necessary
        if (updatePicture) {
            //Clear screen
            window.clear(bg);

            //Set picture and draw the sprite
            sprite.setTexture(loadedPics[slideIndex]);
            window.draw(sprite);
            
            //Update the window
            window.display();
            
            updatePicture = false;
            
            // Set timer
            timer = clock.getElapsedTime();
        }
        
        // Process events
        sf::Event event;
        while (window.pollEvent(event)) {
            // Close window: exit
            if (event.type == sf::Event::Closed) {
                window.close();
            }

            // Escape pressed: exit
            if (event.type == sf::Event::KeyPressed && event.key.code == sf::Keyboard::Q) {
                window.close();
            }
            
            // Arrow left pressed: previous picture
            if (event.type == sf::Event::KeyPressed && event.key.code == sf::Keyboard::Left) {
                slideIndex = (slideIndex+NUM_PICS-1) % NUM_PICS; //Strange C++ modulo
                updatePicture = true;
            }
            // Arrow right pressed: next picture
            if (event.type == sf::Event::KeyPressed && event.key.code == sf::Keyboard::Right) {
                slideIndex = (slideIndex+1) % NUM_PICS;
                updatePicture = true;
            }
        }
        
        // Check time interval
        if (clock.getElapsedTime() > timer+interval) {
            slideIndex = (slideIndex+1) % NUM_PICS;
            updatePicture = true;
        }
    }

    return EXIT_SUCCESS;
}
